'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@angular/core');

function autoChangeDetection(component, inputs, props) {
    const keys = Object.keys(inputs);
    keys.forEach(key => {
        props.set(key, component[key]);
        Object.defineProperty(component, key, {
            get() {
                return props.get(key);
            },
            set(value) {
                props.set(key, value);
                core.ɵdetectChanges(component);
            }
        });
    });
}
function initProps(target, inputs, component) {
    const keys = Object.keys(inputs);
    keys.forEach(key => {
        Object.defineProperty(target, key, {
            get() {
                return component[key];
            },
            set(value) {
                component[key] = value;
            }
        });
    });
}
function initEvents(target, outputs, component) {
    const outputEvents = Object.keys(outputs);
    outputEvents.forEach(outputEvent => {
        component[outputs[outputEvent]].subscribe(info => {
            target.dispatchEvent(new CustomEvent(outputEvent, { detail: info }));
        });
    });
}

function renderNgComponent(componentType, opts) {
    const props = new Map();
    const component = core.ɵrenderComponent(componentType, opts);
    /// @ts-ignore
    autoChangeDetection(component, componentType.ngComponentDef.inputs, props);
}
function renderCustomElement(componentType, injector) {
    /// @ts-ignore
    const { inputs, styles, encapsulation, outputs, selectors, onPush } = componentType.ngComponentDef;
    class CustomElement extends HTMLElement {
        constructor() {
            super();
            this.props = new Map();
            this.rootElement = (encapsulation === core.ViewEncapsulation.ShadowDom)
                ? this.attachShadow({ mode: "open" }) : this;
            this.component = core.ɵrenderComponent(componentType, {
                host: this.rootElement,
                ...(injector ? { injector } : {})
            });
            if (!onPush) {
                autoChangeDetection(this.component, inputs, this.props);
            }
            initProps(this, inputs, this.component);
            initEvents(this, outputs, this.component);
        }
        static get observedAttributes() {
            return [...Object.keys(inputs)];
        }
        attributeChangedCallback(name, oldValue, newValue) {
            const attributes = Object.keys(inputs);
            if (attributes.includes(name)) {
                this[name] = newValue;
            }
        }
        connectedCallback() {
            const cssStyles = styles.join('\n');
            if (cssStyles) {
                const style = document.createElement('style');
                style.textContent = cssStyles;
                this.rootElement.prepend(style);
            }
        }
    }
    customElements.define(selectors[0][0], CustomElement);
}

exports.renderCustomElement = renderCustomElement;
exports.renderNgComponent = renderNgComponent;
